@@ -1,13 +1,13 @@
 package Locale::CLDR::Locales::Bg::Any;
 
 # This file auto generated
-#	on Thu  8 Oct  3:12:46 pm GMT
+#	on Sun 25 Oct  8:35:56 am GMT
 
 use version;
 
-our $VERSION = version->declare('v0.28.0');
+our $VERSION = version->declare('v0.28.1');
 
-use v5.10;
+use v5.10.1;
 use mro 'c3';
 use if $^V ge v5.12.0, feature => 'unicode_strings';
 
